#include <string.h>
#include <time.h>
#include <stdio.h>
#include <stdlib.h>
#include <stddef.h>
#include <stdarg.h>
#include <errno.h>

int console_loglevel = 1; 
int file_loglevel = 1;
char * logfilename = NULL;

/* This defines the format of timestamps in the logs. Set to "" if you do not
 * want any timestamps. The format is just passed to strftime, so see the
 * manpage of strftime for an explanation of what's possible there. */
#define TIMESTAMPFORMAT "%d%m%y.%H%M%S"

void putlog(int level, const char *template, ...) {
	time_t curts;
	char tmps[512];
	va_list ap;
	struct tm brt;
	FILE * lf;

	if ((level > console_loglevel) && (level > file_loglevel)) {
		/* Quick abort: we don't log this anywhere. */
		return;
	}
	if (strcmp(TIMESTAMPFORMAT, "") != 0) {
		curts = time(NULL);
		brt = *localtime(&curts);
		if (strftime(tmps, 511, TIMESTAMPFORMAT, &brt) == 0) {
			strcpy(tmps, "ILLEGAL-TIMESTAMP-FORMAT");
		}
		if (level <= console_loglevel) {
			printf("[%s] ", tmps);
		}
	}
	if (level <= console_loglevel) {
		va_start(ap, template);
		vprintf(template, ap);
		va_end(ap);
		printf("\n");
	}
	if ((logfilename != NULL) && (level <= file_loglevel)) {
		lf = fopen(logfilename, "a");
		if (lf != NULL) {
			if (strcmp(TIMESTAMPFORMAT, "") != 0) {
				fprintf(lf, "[%s] ", tmps);
			}
			va_start(ap, template);
			vfprintf(lf, template, ap);
			va_end(ap);
			fprintf(lf, "\n");
			fclose(lf);
		}
	}
}
